[Checkins] SVN: grokcore.chameleon/trunk/ rename megrok.chameleon --> grokcore.chameleon

Jan-Wijbrand Kolman janwijbrand at gmail.com
Thu Jul 14 09:26:32 EDT 2011


Log message for revision 122220:
  rename megrok.chameleon --> grokcore.chameleon

Changed:
  U   grokcore.chameleon/trunk/CHANGES.txt
  U   grokcore.chameleon/trunk/README.txt
  U   grokcore.chameleon/trunk/buildout.cfg
  U   grokcore.chameleon/trunk/setup.py
  A   grokcore.chameleon/trunk/src/grokcore/
  U   grokcore.chameleon/trunk/src/grokcore/chameleon/README.txt
  U   grokcore.chameleon/trunk/src/grokcore/chameleon/ftesting.zcml
  U   grokcore.chameleon/trunk/src/grokcore/chameleon/tests/__init__.py
  U   grokcore.chameleon/trunk/src/grokcore/chameleon/tests/cpt_fixture/app.py
  U   grokcore.chameleon/trunk/src/grokcore/chameleon/tests/test_megrok_chameleon.py
  D   grokcore.chameleon/trunk/src/megrok/

-=-
Modified: grokcore.chameleon/trunk/CHANGES.txt
===================================================================
--- grokcore.chameleon/trunk/CHANGES.txt	2011-07-14 13:26:08 UTC (rev 122219)
+++ grokcore.chameleon/trunk/CHANGES.txt	2011-07-14 13:26:32 UTC (rev 122220)
@@ -39,7 +39,7 @@
 
 * Made registering of ITranslatorExpressions conditional: if
   ``z3c.pt`` is installed as well, we don't register our own
-  ones. Should fix DuplicationError when using megrok.chameleon
+  ones. Should fix DuplicationError when using grokcore.chameleon
   together with other packages that require z3c.pt like ``z3c.form``
   and dependent packages from grok-ecosphere.
 
@@ -49,7 +49,7 @@
 0.5 (2010-03-03)
 ================
 
-* Added tests to show usage of macros with ``megrok.chameleon``.
+* Added tests to show usage of macros with ``grokcore.chameleon``.
 
 * Removed dependency from ``z3c.pt`` by copying the relevant bits over
   and registering them locally.

Modified: grokcore.chameleon/trunk/README.txt
===================================================================
--- grokcore.chameleon/trunk/README.txt	2011-07-14 13:26:08 UTC (rev 122219)
+++ grokcore.chameleon/trunk/README.txt	2011-07-14 13:26:32 UTC (rev 122220)
@@ -1,8 +1,8 @@
-================
-megrok.chameleon
-================
+=================
+grokcore.chameleon
+=================
 
-`megrok.chameleon` makes it possible to use Chameleon page templates in Grok.
+`grokcore.chameleon` makes it possible to use Chameleon page templates in Grok.
 For more information on Grok and Chameleon page templates see:
 
 - http://pagetemplates.org/
@@ -16,14 +16,14 @@
 ============
 
 To use Chameleon page templates with Grok all you need is to install
-megrok.chameleon as an egg and include its ZCML. The best place to do
-this is to make `megrok.chameleon` a dependency of your application by
+grokcore.chameleon as an egg and include its ZCML. The best place to do
+this is to make `grokcore.chameleon` a dependency of your application by
 adding it to your ``install_requires`` list in ``setup.cfg``. If you
 used grokproject to create your application ``setup.py`` is located in the
 project root. It should look something like this::
 
    install_requires=['setuptools',
-                     'megrok.chameleon',
+                     'grokcore.chameleon',
                      # Add extra requirements here
                      ],
 
@@ -31,14 +31,14 @@
 project's ``buildout.cfg``, you will have to add version number specifications
 for several packages to your ``[versions]`` section.
 
-Then include ``megrok.chameleon`` in your ``configure.zcml``. If you used
+Then include ``grokcore.chameleon`` in your ``configure.zcml``. If you used
 grokproject to create your application it's at
 ``src/<projectname>/configure.zcml``. Add the include line after the include
 line for grok, but before the grokking of the current package. It should look
 something like this::
 
       <include package="grok" />
-      <include package="megrok.chameleon" />
+      <include package="grokcore.chameleon" />
       <grok:grok package="." />
 
 If you use ``autoInclude`` in your ``configure.zcml``, you should not
@@ -47,8 +47,8 @@
 Then run ``bin/buildout`` again. You should now see buildout saying
 something like (where version numbers can vary)::
 
-   Getting distribution for 'megrok.chameleon'.
-   Got megrok.chameleon 0.5.
+   Getting distribution for 'grokcore.chameleon'.
+   Got grokcore.chameleon 0.5.
 
 That's all. You can now start using Chameleon page templates in your
 Grok application.
@@ -56,7 +56,7 @@
 Usage
 =====
 
-``megrok.chameleon`` supports the Grok standard of placing templates in a
+``grokcore.chameleon`` supports the Grok standard of placing templates in a
 templates directory, for example ``app_templates``, so you can use Chameleon
 page templates by simply placing the Chameleon page templates in the templates
 directory, just as you would with regular ZPT templates.
@@ -66,16 +66,16 @@
 extension and a template language implementation so it knows which
 implementation to use.
 
-`megrok.chameleon` declares to use the extension ``*.cpt`` (``Chameleon page
+`grokcore.chameleon` declares to use the extension ``*.cpt`` (``Chameleon page
 template``) for Chameleon page templates.
 
 You can also use Chameleon page templates inline. The syntax for this
 is::
 
-   from megrok.chameleon.components import ChameleonPageTemplate
+   from grokcore.chameleon.components import ChameleonPageTemplate
    index = ChameleonPageTemplate('<html>the html code</html>')
 
 Or if you use files::
 
-   from megrok.genshi.components import ChameleonPageTemplateFile
+   from grokcore.chameleon.components import ChameleonPageTemplateFile
    index = ChameleonPageTemplateFile(filename='thefilename.html')

Modified: grokcore.chameleon/trunk/buildout.cfg
===================================================================
--- grokcore.chameleon/trunk/buildout.cfg	2011-07-14 13:26:08 UTC (rev 122219)
+++ grokcore.chameleon/trunk/buildout.cfg	2011-07-14 13:26:32 UTC (rev 122220)
@@ -6,7 +6,7 @@
 extensions = buildout.dumppickedversions
 
 [versions]
-megrok.chameleon = 
+grokcore.chameleon = 
 Chameleon = 2.0-rc9
 ordereddict = 1.1
 unittest2 = 0.5.1
@@ -14,12 +14,12 @@
 
 [interpreter]
 recipe = zc.recipe.egg
-eggs = megrok.chameleon
+eggs = grokcore.chameleon
 interpreter = python
 
 [test]
 recipe = zc.recipe.testrunner
 eggs =
-   megrok.chameleon
-   megrok.chameleon[test]
+   grokcore.chameleon
+   grokcore.chameleon[test]
 defaults = ['--tests-pattern', '^f?tests$', '-v']

Modified: grokcore.chameleon/trunk/setup.py
===================================================================
--- grokcore.chameleon/trunk/setup.py	2011-07-14 13:26:08 UTC (rev 122219)
+++ grokcore.chameleon/trunk/setup.py	2011-07-14 13:26:32 UTC (rev 122220)
@@ -19,12 +19,12 @@
 
 long_description = (open('README.txt').read() +
                     '\n\n' +
-                    open(os.path.join('src', 'megrok', 'chameleon',
+                    open(os.path.join('src', 'grokcore', 'chameleon',
                                       'README.txt')).read() +
                     '\n\n' +
                     open('CHANGES.txt').read())
 
-setup(name='megrok.chameleon',
+setup(name='grokcore.chameleon',
       version=version,
       description="Chameleon page template support for Grok",
       long_description=long_description,
@@ -40,11 +40,11 @@
       keywords="grok chameleon template",
       author="Uli Fouquet",
       author_email="grok-dev at zope.org",
-      url="http://pypi.python.org/pypi/megrok.chameleon",
+      url="http://pypi.python.org/pypi/grokcore.chameleon",
       license="ZPL",
       package_dir={'': 'src'},
       packages=find_packages('src'),
-      namespace_packages=['megrok'],
+      namespace_packages=['grokcore'],
       include_package_data=True,
       zip_safe=False,
       install_requires=install_requires,

Modified: grokcore.chameleon/trunk/src/grokcore/chameleon/README.txt
===================================================================
--- grokcore.chameleon/trunk/src/megrok/chameleon/README.txt	2011-07-14 13:18:04 UTC (rev 122218)
+++ grokcore.chameleon/trunk/src/grokcore/chameleon/README.txt	2011-07-14 13:26:32 UTC (rev 122220)
@@ -4,7 +4,7 @@
 
 Grok-support for using chameleon driven templates.
 
-With `megrok.chameleon` you can use templates parsed and rendered by
+With `grokcore.chameleon` you can use templates parsed and rendered by
 `Chameleon`_ using the Zope Page Template templating language.
 
 Chameleon Zope page templates
@@ -45,18 +45,18 @@
     >>> template_dir = os.path.join(cpt_fixture, 'app_templates')
 
 We register everything. Before we can grok our fixture, we have to
-grok the `megrok.chameleon` package. This way the new template types
+grok the `grokcore.chameleon` package. This way the new template types
 are registered with the framework:
 
     >>> import grokcore.view
-    >>> grokcore.view.testing.grok('megrok.chameleon')
-    >>> grokcore.view.testing.grok('megrok.chameleon.tests.cpt_fixture')
+    >>> grokcore.view.testing.grok('grokcore.chameleon')
+    >>> grokcore.view.testing.grok('grokcore.chameleon.tests.cpt_fixture')
 
 We create a mammoth, which should provide us a bunch of chameleon page
 template driven views and put it in the database to setup location
 info::
 
-    >>> from megrok.chameleon.tests.cpt_fixture.app import Mammoth
+    >>> from grokcore.chameleon.tests.cpt_fixture.app import Mammoth
     >>> manfred = Mammoth()
     >>> getRootFolder()['manfred'] = manfred
 
@@ -203,10 +203,10 @@
        &lt;PageTemplateFile ...vars.cpt&gt;
     <BLANKLINE>
       view (the associated view):
-       &lt;megrok.chameleon.tests.cpt_fixture.app.Vars object at 0x...&gt;
+       &lt;grokcore.chameleon.tests.cpt_fixture.app.Vars object at 0x...&gt;
     <BLANKLINE>
       context (the context of the view):
-       &lt;megrok.chameleon.tests.cpt_fixture.app.Mammoth object at 0x...&gt;
+       &lt;grokcore.chameleon.tests.cpt_fixture.app.Mammoth object at 0x...&gt;
     <BLANKLINE>
       request (the current request):
        CONTENT_LENGTH:	0
@@ -236,7 +236,7 @@
 We can also define inline templates. In our ``app.py`` we defined an
 inline template like this::
 
-  from megrok.chameleon import components
+  from grokcore.chameleon import components
 
   ...
 
@@ -255,7 +255,7 @@
 TAL expressions
 ===============
 
-Starting with ``megrok.chameleon`` 0.5 we deploy the all-in-one
+Starting with ``grokcore.chameleon`` 0.5 we deploy the all-in-one
 `Chameleon`_ package.
 
 What TAL/TALES expressions in templates are supported depends mainly
@@ -265,7 +265,7 @@
 A list of all supported expressions and statements can be found at the
 `chameleon.zpt documentation
 <http://chameleon.repoze.org/docs/latest/zpt.html>`_. The additional
-TALES expressions provided by ``megrok.chameleon`` are:
+TALES expressions provided by ``grokcore.chameleon`` are:
 
 * ``exists``
      Tell whether a name exists in the templates' namespace.
@@ -279,7 +279,7 @@
 * ``provider``
      Support for viewlet providers.
 
-.. note:: Starting with ``megrok.chameleon`` 0.5 support for the
+.. note:: Starting with ``grokcore.chameleon`` 0.5 support for the
           Python expression ``exists()`` has been dropped. The TALES
           expression ``exists: path/to/something`` is still available.
 
@@ -287,7 +287,7 @@
 expressions. This also includes a viewlet::
 
    import grok
-   from megrok.chameleon import components
+   from grokcore.chameleon import components
 
    class Mammoth(grok.Application, grok.Container):
        pass
@@ -368,7 +368,7 @@
 Macros
 ======
 
-With ``megrok.chameleon`` we can also use macros, although it is a bit
+With ``grokcore.chameleon`` we can also use macros, although it is a bit
 different from regular Zope page templates.
 
 We can define macros like this:

Modified: grokcore.chameleon/trunk/src/grokcore/chameleon/ftesting.zcml
===================================================================
--- grokcore.chameleon/trunk/src/megrok/chameleon/ftesting.zcml	2011-07-14 13:18:04 UTC (rev 122218)
+++ grokcore.chameleon/trunk/src/grokcore/chameleon/ftesting.zcml	2011-07-14 13:26:32 UTC (rev 122220)
@@ -1,8 +1,8 @@
 <configure
    xmlns="http://namespaces.zope.org/zope"
    xmlns:grok="http://namespaces.zope.org/grok"
-   i18n_domain="megrok.chameleon"
-   package="megrok.chameleon">
+   i18n_domain="grokcore.chameleon"
+   package="grokcore.chameleon">
 
   <include package="zope.component" file="meta.zcml"/>
   <include package="zope.security" file="meta.zcml"/>
@@ -14,5 +14,5 @@
   <include package="zope.container"/>
   <include package="zope.app.appsetup"/>
   <include package="grokcore.viewlet"/>
-  <include package="megrok.chameleon"/>
+  <include package="grokcore.chameleon"/>
 </configure>

Modified: grokcore.chameleon/trunk/src/grokcore/chameleon/tests/__init__.py
===================================================================
--- grokcore.chameleon/trunk/src/megrok/chameleon/tests/__init__.py	2011-07-14 13:18:04 UTC (rev 122218)
+++ grokcore.chameleon/trunk/src/grokcore/chameleon/tests/__init__.py	2011-07-14 13:26:32 UTC (rev 122220)
@@ -14,7 +14,7 @@
 # $Id$ $Rev$ $Author$ $Date$
 """A functional test layer.
 """
-import megrok.chameleon
+import grokcore.chameleon
 from zope.app.wsgi.testlayer import BrowserLayer
 
-FunctionalLayer = BrowserLayer(megrok.chameleon, 'ftesting.zcml')
+FunctionalLayer = BrowserLayer(grokcore.chameleon, 'ftesting.zcml')

Modified: grokcore.chameleon/trunk/src/grokcore/chameleon/tests/cpt_fixture/app.py
===================================================================
--- grokcore.chameleon/trunk/src/megrok/chameleon/tests/cpt_fixture/app.py	2011-07-14 13:18:04 UTC (rev 122218)
+++ grokcore.chameleon/trunk/src/grokcore/chameleon/tests/cpt_fixture/app.py	2011-07-14 13:26:32 UTC (rev 122220)
@@ -1,7 +1,7 @@
 from grokcore.component.interfaces import IContext
 from zope.container.btree import BTreeContainer
 from zope.interface import implements
-from megrok.chameleon import components
+from grokcore.chameleon import components
 
 import grokcore.view
 import grokcore.viewlet

Modified: grokcore.chameleon/trunk/src/grokcore/chameleon/tests/test_megrok_chameleon.py
===================================================================
--- grokcore.chameleon/trunk/src/megrok/chameleon/tests/test_megrok_chameleon.py	2011-07-14 13:18:04 UTC (rev 122218)
+++ grokcore.chameleon/trunk/src/grokcore/chameleon/tests/test_megrok_chameleon.py	2011-07-14 13:26:32 UTC (rev 122220)
@@ -1,15 +1,15 @@
 """Test setup for megrok.chameleon.
 """
 import doctest
 import unittest
 import zope.interface
 import zope.component
-import megrok.chameleon
+import grokcore.chameleon
 
 from zope.traversing.interfaces import ITraversable
 from zope.traversing.browser.interfaces import IAbsoluteURL
 from zope.publisher.interfaces.browser import IBrowserRequest
-from megrok.chameleon.tests import FunctionalLayer
+from grokcore.chameleon.tests import FunctionalLayer
 
 FLAGS = (doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE)
 
@@ -34,7 +34,7 @@
         factory=DummyResource,
         adapts=(IBrowserRequest,),
         provides=zope.interface.Interface,
-        name='megrok.chameleon.tests.cpt_fixture'
+        name='grokcore.chameleon.tests.cpt_fixture'
         )
     return
 
@@ -46,7 +46,7 @@
     test = doctest.DocFileSuite(
         'README.txt',
         setUp=setUpStatic,
-        package=megrok.chameleon,
+        package=grokcore.chameleon,
         globs=dict(
             getRootFolder=FunctionalLayer.getRootFolder,
             ),
@@ -1,15 +1,15 @@
-"""Test setup for megrok.chameleon.
+"""Test setup for grokcore.chameleon.
 """
 import doctest



More information about the checkins mailing list